@@ -6,9 +6,6 @@ use 5.0100;
 
 use Moose;
 extends 'Business::UPS::Tracking::Shipment';
-__PACKAGE__->meta->error_class("Business::UPS::Tracking::Exception");
-
-our $VERSION = $Business::UPS::Tracking::VERSION;
 
 =encoding utf8
 
